# Optimal Stimuli


## Naturalistic

::: flyvis.analysis.optimal_stimuli.FindOptimalStimuli

::: flyvis.analysis.optimal_stimuli.OptimalStimulus

## Artificial

::: flyvis.analysis.optimal_stimuli.GeneratedOptimalStimulus

::: flyvis.analysis.optimal_stimuli.RegularizedOptimalStimulus

## Visualization

::: flyvis.analysis.optimal_stimuli.StimResponsePlot

::: flyvis.analysis.optimal_stimuli.plot_stim_response
